==> ejc-procurement-api-3.0.0-20251202.073932-7-sources.jar: com/ejianc/business/procurement/vo/CatalogItemVO.java <==
package com.ejianc.business.procurement.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 一级集采目录-明细
 * 
 * @author generator
 * 
 */
public class CatalogItemVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 编码
    private String name; // 名称
    private String description; // 描述
    private Integer sequence; // 排序
    private Integer enabled; // 1:启用、0:停用
    private Long categoryId; // 分类
    private String businessType; // 业务类别1-工程，2-货物，3-服务


    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    
}

==> ejc-procurement-api-3.0.0-20251202.092503-10-sources.jar: com/ejianc/business/procurement/vo/CatalogItemVO.java <==
package com.ejianc.business.procurement.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 一级集采目录-明细
 * 
 * @author generator
 * 
 */
public class CatalogItemVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 编码
    private String name; // 名称
    private String description; // 描述
    private Integer sequence; // 排序
    private Integer enabled; // 1:启用、0:停用
    private Long categoryId; // 分类
    private String businessType; // 业务类别1-工程，2-货物，3-服务

    private String categoryCode; // 分类编码
    private String categoryName; // 分类名称

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    
}
